@@ -97,11 +97,16 @@ impl<W: World + Debug, Out: io::Write> Writer<W> for Json<Out> {
                     .write_all(
                         serde_json::to_string(&self.features)
                             .unwrap_or_else(|e| {
+                                // TODO: Use "{e}" syntax once MSRV bumps above
+                                //       1.58.
                                 panic!("Failed to serialize JSON: {}", e)
                             })
                             .as_bytes(),
                     )
-                    .unwrap_or_else(|e| panic!("Failed to write JSON: {}", e));
+                    .unwrap_or_else(|e| {
+                        // TODO: Use "{e}" syntax once MSRV bumps above 1.58.
+                        panic!("Failed to write JSON: {}", e)
+                    });
             }
             _ => {}
         }
@@ -204,11 +209,13 @@ impl<Out: io::Write> Json<Out> {
 
         let mut duration = || {
             let started = self.started.take().unwrap_or_else(|| {
+                // TODO: Use "{hook_ty}" syntax once MSRV bumps above 1.58.
                 panic!("No `Started` event for `{} Hook`", hook_ty)
             });
             meta.at
                 .duration_since(started)
                 .unwrap_or_else(|e| {
+                    // TODO: Use "{e}" syntax once MSRV bumps above 1.58.
                     panic!(
                         "Failed to compute duration between {:?} and {:?}: {}",
                         meta.at, started, e,
@@ -265,6 +272,7 @@ impl<Out: io::Write> Json<Out> {
             meta.at
                 .duration_since(started)
                 .unwrap_or_else(|e| {
+                    // TODO: Use "{e}" syntax once MSRV bumps above 1.58.
                     panic!(
                         "Failed to compute duration between {:?} and {:?}: {}",
                         meta.at, started, e,
